==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/GetLinkedWorkspacePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.GetLinkedWorkspacePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property linkName Friendly name of the linked workspace
 * @property resourceGroupName Name of the resource group in which workspace is located.
 * @property workspaceName Name of Azure Machine Learning workspace.
 */
public data class GetLinkedWorkspacePlainArgs(
    public val linkName: String,
    public val resourceGroupName: String,
    public val workspaceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.GetLinkedWorkspacePlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.GetLinkedWorkspacePlainArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.GetLinkedWorkspacePlainArgs.builder()
            .linkName(linkName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetLinkedWorkspacePlainArgs].
 */
@PulumiTagMarker
public class GetLinkedWorkspacePlainArgsBuilder internal constructor() {
    private var linkName: String? = null

    private var resourceGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value Friendly name of the linked workspace
     */
    @JvmName("nylawellhtbhjkww")
    public suspend fun linkName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.linkName = mapped
    }

    /**
     * @param value Name of the resource group in which workspace is located.
     */
    @JvmName("oolcjsqsprscdyaj")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of Azure Machine Learning workspace.
     */
    @JvmName("lkynmohygakpnewt")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetLinkedWorkspacePlainArgs = GetLinkedWorkspacePlainArgs(
        linkName = linkName ?: throw PulumiNullFieldException("linkName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/GetLinkedWorkspacePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.GetLinkedWorkspacePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property linkName Friendly name of the linked workspace
 * @property resourceGroupName Name of the resource group in which workspace is located.
 * @property workspaceName Name of Azure Machine Learning workspace.
 */
public data class GetLinkedWorkspacePlainArgs(
    public val linkName: String,
    public val resourceGroupName: String,
    public val workspaceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.GetLinkedWorkspacePlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.GetLinkedWorkspacePlainArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.GetLinkedWorkspacePlainArgs.builder()
            .linkName(linkName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetLinkedWorkspacePlainArgs].
 */
@PulumiTagMarker
public class GetLinkedWorkspacePlainArgsBuilder internal constructor() {
    private var linkName: String? = null

    private var resourceGroupName: String? = null

    private var workspaceName: String? = null

    /**
     * @param value Friendly name of the linked workspace
     */
    @JvmName("mtmcevhyidbmryvu")
    public suspend fun linkName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.linkName = mapped
    }

    /**
     * @param value Name of the resource group in which workspace is located.
     */
    @JvmName("rmmblpdeibawkhnf")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Name of Azure Machine Learning workspace.
     */
    @JvmName("avkdyggfmhbqahty")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetLinkedWorkspacePlainArgs = GetLinkedWorkspacePlainArgs(
        linkName = linkName ?: throw PulumiNullFieldException("linkName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
    )
}
